///////////////////////////////////////////////////////////////////////////////
// EAPerson
// By: Kamek (kamek@postalleague.com)
// For: EA
//
// Base class for most EA pawns.
///////////////////////////////////////////////////////////////////////////////
class EAPerson extends EDPerson
	notplaceable
	abstract;

///////////////////////////////////////////////////////////////////////////////
///////////////////////////////////////////////////////////////////////////////
var(Cell) class<P2Weapon> CellPhoneClass;
var(Cell) bool bCellUser;
var(Cell) sound CellBeep;
var(Cell) sound CellRing;
var KevlarMesh ArmorMesh;		// Model of kevlar armor you're wearing on your person

var(Footsteps) Sound FootStepSounds[5];
var(Footsteps) bool bDoFootsteps;

var(Character) array<MeshAnimation> ExtraAnims;

///////////////////////////////////////////////////////////////////////////////
///////////////////////////////////////////////////////////////////////////////
var float StuckTime;				// How long the player has been 'stuck'. Determined below. If they are not
									// moving in Z for too long (MAX_STUCK_TIME),
									// then warp them to the nearest good pathnode.
var float StuckCheckRadius;			// Size around which you check for pathnodes to warp to
var PathNode LastUnstuckPoint;		// Save the last point we warped to, after being unstuck. Don't use it
									// the very next time, to keep us from infinite unsticking--still stuck
									// scenarios.
var bool bPlayingFootstepSound;	// Set to true when you play a step, false after timer is
								// called again

///////////////////////////////////////////////////////////////////////////////
///////////////////////////////////////////////////////////////////////////////
const MELEE_BLOCK_MIN_HESTON = 0.25;
const MELEE_BLOCK_MAX_HESTON = 0.50;

const MELEE_BLOCK_MIN_INSANE = 0.50;
const MELEE_BLOCK_MAX_INSANE = 1.00;

const MAX_STUCK_TIME				=	2.0;
const STUCK_RADIUS					=	2048;

const RUN_FOOTSTEP_TIME		=	0.35;
const WALK_FOOTSTEP_TIME	=	0.60;

const WALK_VOL				= 0.07;
//=	0.07;
const RUN_VOL				= 0.2;
//=	0.2;

const FOOTSTEP_RADIUS			=	100;
const FOOTSTEP_RADIUS_MP		=	200;
const FOOTSTEP_RADIUS_LOCAL_MP	=	20;

const INSANE_MEDGUN_PCT			= 0.5;
const INSANE_BIGGUN_PCT			= 0.25;
const INSANE_UBERGUN_PCT		= 0.005;
const INSANE_MELEE_PCT			= 0.25;

// Headshots in MP do a lot more damage
const HEAD_RATIO_MP				=	0.8;
const HEAD_SHOT_DAMAGE_MP		=	10.0;	// tries to make it so two pistol head shots kill a guy

const HEAD_RATIO_OF_FULL_HEIGHT	=	0.7;
const DISTANCE_TO_EXPLODE_HEAD	=	150;
const DISTANCE_TO_PUNCTURE_HEAD	=	32;

const MOVE_BUFFER = 100;

///////////////////////////////////////////////////////////////////////////////
// blow up into little pieces (implemented in subclass)		
///////////////////////////////////////////////////////////////////////////////
simulated function Chunk(int Damage)
{
	local PawnExplosion exp;

	bChunkedUp=true;

	if ( Controller != None )
	{
		if ( Controller.bIsPlayer )
			Controller.PawnDied(self);
		else
		{
			Controller.Destroy();
			Controller = None;
		}
	}

	// Make big blood splat if we can
	if(class'P2Player'.static.BloodMode())
	{
		exp = spawn(class'PawnExplosion',,,Location);
		exp.FitToNormal(vect(0, 0, 1));
	}
	else // dust if we're lame
		DustHit(Location, Velocity);

	// Get rid of me nicely
	Destroy();
}

///////////////////////////////////////////////////////////////////////////////
// blow up into little pieces with guts and intestines
///////////////////////////////////////////////////////////////////////////////
simulated function ChunkUp(int Damage)
{
	local PawnExplosion exp;

	bChunkedUp=true;

	if ( Controller != None )
	{
		if ( Controller.bIsPlayer )
			Controller.PawnDied(self);
		else
		{
			Controller.Destroy();
			Controller = None;
		}
	}

	// Make big blood splat if we can
	if(class'P2Player'.static.BloodMode())
	{
		exp = spawn(class'PawnExplosion',,,Location);
		exp.FitToNormal(vect(0, 0, 1));
	}
	else // dust if we're lame
		DustHit(Location, Velocity);

	// Get rid of me nicely
	Destroy();
}

///////////////////////////////////////////////////////////////////////////////
// Play 3rd person shooting anims
// Includes fisting anims
///////////////////////////////////////////////////////////////////////////////
simulated function PlayFiring(float Rate, name FiringMode)
{
	local EWeaponHoldStyle wstyle;
	local bool StandingStill;

	// If he's not moving and not rotating make a recoil
	// Some weapons (like guns) don't want a recoil if you're
	// moving too much
	StandingStill = (NoLegMotion()
					&& (!bPlayer
						|| (Controller != None
							&& Controller.DesiredRotation == Controller.Rotation)));

}

///////////////////////////////////////////////////////////////////////////////
///////////////////////////////////////////////////////////////////////////////
function PostBeginPlay()
{
	Super.PostBeginPlay();

	StuckCheckRadius = STUCK_RADIUS;
}

///////////////////////////////////////////////////////////////////////////////
///////////////////////////////////////////////////////////////////////////////
function SetupBoltons()
{
	local int i;

	Super.SetupBoltons();

	for (i=0; i<ArrayCount(Boltons); i++)
	{
		if (Boltons[i].Part != None && Boltons[i].bAttachToHead)
			Boltons[i].Part.SetDrawScale3d(MyHead.DrawScale3D);
	}
}

///////////////////////////////////////////////////////////////////////////////
// Decide on a prize for a quick kill
///////////////////////////////////////////////////////////////////////////////
function PickQuickKillPrize(int KillIndex)
{
	local class<Inventory> invclass;
	local Inventory newone;

	switch(KillIndex)
	{
		case 0:
			invclass = class'DonutInv';
		break;
		case 1:
			invclass = class'MoneyInv';
		break;
		case 2:
			invclass = class'FastFoodInv';
		break;
		case 3:
			invclass = class'MaDBeerInv';
		break;
		case 4:
			invclass = class'CrackInv';
		break;
		case 5:
			invclass = class'MaDWeedInv';
		break;
		case 6:
			invclass = class'CatnipInv';
		break;
	}
	newone = spawn(invclass, self);
	TossThisInventory(vector(Rotation), newone);
}

///////////////////////////////////////////////////////////////////////////////
// toss out the inventory passed in
///////////////////////////////////////////////////////////////////////////////
function bool TossThisInventory(vector TossVel, Inventory ThisInv)
{
	local vector X,Y,Z;
	local Rotator userot;
	local P2Weapon ThisWeap;

	if(ThisInv == None)
		return false;

	// Really make it stop doing it's stuff
	// And don't drop things that can't be dropped
	ThisWeap = P2Weapon(ThisInv);
	if(ThisWeap != None)
	{
		if(!ThisWeap.bCanThrow
			|| (!ThisWeap.bCanThrowMP
				&& !Level.Game.bIsSinglePlayer))
			return false;

		ThisWeap.ForceEndFire();
	}

	// Comment out the 1409 fix
/*
	if(P2PowerupInv(ThisInv) != None)
	{
		if(!P2PowerupInv(ThisInv).bCanThrow
			// 1409 fix, make sure you have stuff to throw!
			// Before this, you could use a crack pipe, then throw it quickly as the
			// smoke was coming out, and you'd still get the health and the crack pipe back--fixed!
			|| P2PowerupInv(ThisInv).Amount <= 0)
			return false;
	}
*/

	ThisInv.velocity = TossVel;
	userot = Rotation;
	userot.Yaw = FRAnd()*65535;
	GetAxes(userot,X,Y,Z);
	// And make the ThisWeap align with the direction of the throw
	ThisInv.SetRotation(userot);
	ThisInv.DropFrom(Location + 0.3 * CollisionRadius * X + CollisionRadius * Z);
	return true;
}

///////////////////////////////////////////////////////////////////////////////
// Decide if he's stuck or not
///////////////////////////////////////////////////////////////////////////////
function bool DetectStuckPlayer(float DeltaTime)
{
	// If you're falling and not moving for too long, you're stuck
	if(Physics == PHYS_Falling
		&& !bIsCrouched)
	{
		// If you're not moving in z for too long
		if(Velocity.z == 0)
		{
			StuckTime += DeltaTime;

			// Now that he's really stuck, move him
			if(StuckTime > MAX_STUCK_TIME)
			{
				StuckTime = 0;
				return true;
			}
		}
		else
			StuckTime = 0;
	}
	return false;
}

///////////////////////////////////////////////////////////////////////////////
// Find the nearest free pathnode to the stuck player, and put him there
// Warps him to each possible spot to make sure it will work. But it doesn't
// warp him back, it just uses the oldloc to test from. The last one you warped
// him to will have to be the closest to oldloc.
///////////////////////////////////////////////////////////////////////////////
function HandleStuckPlayer()
{
	local PathNode pn, savepn;
	local float closedist, usedist;
	local vector useloc, oldloc;

	Warn(self$" ERROR! NPC WAS STUCK here: "$Location);

	oldloc = Location;

	closedist = StuckCheckRadius;
	// Check pathnodes in a given radius
	foreach RadiusActors(class'Pathnode', pn, StuckCheckRadius, oldloc)
	{
		usedist = VSize(pn.Location - oldloc);
		if(LastUnstuckPoint	!= pn		// Not where we last unstuck ourself from
			&& usedist < closedist		// closest one
			&& !pn.bBlocked)			// not blocked
		{
			// Warp the player there now, to make sure the spot was
			// okay for him to be there. If this happens, it will only
			// work with the closest node, so this will also be the final move
			useloc = pn.Location;
			// Add just enough buffer to pathnode, to make sure he somehow doesn't
			// get warped to a point below the floor, and then fall through the floor.
			useloc.z += (CollisionHeight/2);
			if(SetLocation(useloc))
			{
				closedist = usedist;
				savepn = pn;
			}
		}
	}

	if(savepn != None)
	{
		//mypawnfix
		StuckCheckRadius = STUCK_RADIUS;
		LastUnstuckPoint = savepn;	// Save where we last unstuck from so as to not use it again, next time
		Warn(self$" UNsticking NPC--warping him to "$savepn);
	}
	else
	{
		Warn(self$" UNsticking warp failed");
		// You've failed, then increase you're check area
		StuckCheckRadius += STUCK_RADIUS;
	}
}

///////////////////////////////////////////////////////////////////////////////
// Adds all the required equipment and picks out the urethra.
// Do this here so we access to the inventory package for specific things
// like HandsWeapon and UrethraWeapon.
///////////////////////////////////////////////////////////////////////////////
function AddDefaultInventory()
{
	local int i, j, randpick;
	local Inventory thisinv;
	local P2PowerupInv pinv;
	local P2Weapon p2weap;
	local class<P2Weapon> p2weapclass;
	local int usedam;
	local int Count;
	local bool bWeaponsGranted;

	// Only let this be called once
	if (!bGotDefaultInventory)
	{
		//Log(self$" PersonPawn.AddDefaultInventory() is adding inventory");
		// Everyone gets hands, so add that explicitly here
		thisinv = CreateInventoryByClass(class'Inventory.HandsWeapon');

		// Give them a cell phone
		if (bCellUser && CellPhoneClass != None)
			CreateInventoryByClass(CellPhoneClass);
		else // No cell phone class means no calls
			bCellUser = False;

		// Handle money seperately
		if(MaxMoneyToStart > 0)
		{
			pinv = P2PowerupInv(CreateInventoryByClass(class'Inventory.MoneyInv'));
			pinv.SetAmount(MaxMoneyToStart);
		}

		// Add in the extra stuff now
		for ( i=0; i<BaseEquipment.Length; i++ )
		{
			if (BaseEquipment[i].weaponclass != None)
			{
				//log(self$" base equipment "$i$" weap "$BaseEquipment[i].weaponclass);
				p2weapclass = class<P2Weapon>(BaseEquipment[i].weaponclass);

				// If you're in Liebermode and this is a violent weapon, change
				// it to a weak one (but don't bother the player)
				if(p2weapclass != None
					&& P2GameInfo(Level.Game).InLiebermode()
					&& p2weapclass.default.ViolenceRank >= class'GSelectWeapon'.default.ViolenceRank
					&& !bPlayer)
				{
					// If you're a cop, don't let them have their pistols/machine guns
					// (leave them with batons)
					if(class == class'Police')
						BaseEquipment[i].weaponclass = None;
					else // Other people get random melee weapons in their inventories
					{
						randpick = Rand(3);
						switch(randpick)
						{
							case 0:
								BaseEquipment[i].weaponclass = class'EABatonWeapon';
								break;
							case 1:
								BaseEquipment[i].weaponclass = class'EAShovelWeapon';
								break;
							case 2:
								BaseEquipment[i].weaponclass = class'EAShockerWeapon';
								break;
						}
					}
				}

				// If you have anything at all
				if(BaseEquipment[i].weaponclass != None)
				{
					// Create the weapon from this base equipment index
					thisinv = CreateInventoryByClass(BaseEquipment[i].weaponclass);

					// Special weapon handling:
					// Keep track of the foot now, because we can't do it below (like the urethra)
					// --it's not added to the inventory list
					// Link up your foot
					if(FootWeapon(thisinv) != None)
					{
						MyFoot = P2Weapon(thisinv);
						MyFoot.GotoState('Idle');
						MyFoot.bJustMade=false;
						if(Controller != None)
							Controller.NotifyAddInventory(MyFoot);
						ClientSetFoot(P2Weapon(thisinv));
					}
				}
			}
		}

		// If you're in heston mode, no matter what, always give them some more random guns
		// (unless you're the player)
		if(P2GameInfo(Level.Game).InHestonMode()
			&& !bPlayer)
		{
			randpick = Rand(6);
			switch(randpick)
			{
				case 0:
					CreateInventoryByClass(class'DesertEagleWeapon');
					break;
				case 1:
					CreateInventoryByClass(class'M870Weapon');
					break;
				case 2:
					CreateInventoryByClass(class'M16A2Weapon');
					break;
				case 3:
					CreateInventoryByClass(class'SMEGWeapon');
					break;
				case 4:
					CreateInventoryByClass(class'MaDSPistolWeapon');
					break;
				case 5:
					CreateInventoryByClass(class'MaDSMPWeapon');
					break;
			}
			// And bump them up to be ready to fight
			if(PainThreshold < 1.0)
				PainThreshold = 1.0;

			if(Cajones < 1.0)
				Cajones = 1.0;

			// Make them block melee attacks more often
			if (BlockMeleeFreq < MELEE_BLOCK_MIN_HESTON)
				BlockMeleeFreq = frand() * (MELEE_BLOCK_MAX_HESTON - MELEE_BLOCK_MIN_HESTON) + MELEE_BLOCK_MIN_HESTON;
		}

		// If you're in Insane-o mode, no matter what, always give them some more random guns
		// (unless you're the player) (but give them more than heston)
		if(P2GameInfo(Level.Game).InInsaneMode()
			&& !bPlayer)
		{
			// In EA, people get lots of guns in Insane Mode.
			if (FRand() <= INSANE_UBERGUN_PCT)
			{
				// Give them an "uber" gun
				bWeaponsGranted = true;
				randpick = Rand(3);
				switch(randpick)
				{
					case 0:
						CreateInventoryByClass(class'EAGrenadeLauncherWeapon');
						break;
					case 1:
						CreateInventoryByClass(class'HolyWeapon');
						break;
					case 2:
						CreateInventoryByClass(class'EAPlagueWeapon');
						break;
				}
			}

			if (FRand() <= INSANE_BIGGUN_PCT)
			{
				// Give them a bigger gun
				bWeaponsGranted = true;
				randpick = Rand(5);
				switch(randpick)
				{
					case 0:
						CreateInventoryByClass(class'GLauncherWeapon');
						break;
					case 1:
						CreateInventoryByClass(class'M136AT4Weapon');
						break;
					case 2:
						CreateInventoryByClass(class'EANapalmWeapon');
						break;
					case 3:
						CreateInventoryByClass(class'MaDSyringeWeapon');
						break;
					case 4:
						CreateInventoryByClass(class'MaDZyclonBWeapon');
						break;
				}
			}

			if (FRand() <= INSANE_MEDGUN_PCT)
			{
				// Give them a medium-sized gun
		//		log(self@"granting medium gun");
				bWeaponsGranted = true;
				randpick = Rand(9);
				switch(randpick)
				{
					case 0:
						CreateInventoryByClass(class'EACowHeadWeapon');
						break;
					case 1:
						CreateInventoryByClass(class'EAGrenadeWeapon');
						break;
					case 2:
						CreateInventoryByClass(class'EAMolotovWeapon');
						break;
					case 3:
						CreateInventoryByClass(class'SMEGWeapon');
						break;
					case 4:
						CreateInventoryByClass(class'MaDBombWeapon');
						break;
					case 5:
						CreateInventoryByClass(class'MaDColtWeapon');
						break;
					case 6:
						CreateInventoryByClass(class'MaDShurikenWeapon');
						break;
					case 7:
						CreateInventoryByClass(class'EADoubleBarrelWeapon');
						break;
					case 8:
						CreateInventoryByClass(Class'FlameWeapon');
						break;
					case 9:
						CreateInventoryByClass(class'EAScissorsWeapon');
						break;
					case 10:
						CreateInventoryByClass(class'EACrossbowWeapon');
						break;
				}
			}

			if (FRand() <= INSANE_MELEE_PCT)
			{
				// Give them a cool melee weapon
		//		log(self@"granting melee weapon");
				bWeaponsGranted = true;
				randpick = Rand(7);
				switch(randpick)
				{
					case 0:
						CreateInventoryByClass(class'EAMacheteWeapon');
						break;
					case 1:
						CreateInventoryByClass(class'EASledgeWeapon');
						break;
					case 2:
						CreateInventoryByClass(class'EAScytheWeapon');
						break;
					case 3:
						CreateInventoryByClass(class'EAPitchforkWeapon');
						break;
					case 4:
						CreateInventoryByClass(class'EAKatanaWeapon');
						break;
					case 5:
						CreateInventoryByClass(class'MaDBAxeWeapon');
						break;
					case 6:
						CreateInventoryByClass(class'BaseballBatWeapon');
						break;
					case 7:
						CreateInventoryByClass(Class'EAChainsawWeapon');
						break;
					case 8:
						CreateInventoryByClass(Class'EAWoodenBatWeapon');
						break;
					case 9:
						CreateInventoryByClass(Class'EABatWeapon');
						break;
					case 10:
						CreateInventoryByClass(Class'EABatWeapon');
						break;
					case 11:
						CreateInventoryByClass(Class'EAButterflyKnifeWeapon');
						break;
					case 12:
						CreateInventoryByClass(Class'EAAxeWeapon');
						break;
					case 13:
						CreateInventoryByClass(Class'EAFistsWeapon');
						break;
					case 14:
						CreateInventoryByClass(Class'EADrillWeapon');
						break;
					case 15:
						CreateInventoryByClass(Class'EADustersWeapon');
						break;
					case 16:
						CreateInventoryByClass(Class'EAHammerWeapon');
						break;
					case 17:
						CreateInventoryByClass(Class'EABatonWeapon');
						break;
					case 18:
						CreateInventoryByClass(Class'EAShovelWeapon');
						break;
					case 19:
						CreateInventoryByClass(Class'EAFistsWeapon');
						break;
					case 20:
						CreateInventoryByClass(Class'EAShovelWeapon');
						break;
					case 21:
						CreateInventoryByClass(Class'EAFistsWeapon');
						break;
					case 22:
						CreateInventoryByClass(Class'EAMeatCleaverWeapon');
						break;
					case 23:
						CreateInventoryByClass(Class'EAShearsWeapon');
						break;
					case 24:
						CreateInventoryByClass(Class'EASickleWeapon');
						break;
					case 25:
						CreateInventoryByClass(Class'EAFootWeapon');
						break;
					case 26:
						CreateInventoryByClass(Class'AWPKatanaWeapon');
						break;
				}
			}

			if (!bWeaponsGranted)
			{
				// Give them the standard
		//		log(self@"granting small gun");
				randpick = Rand(6);
				switch(randpick)
				{
					case 0:
						CreateInventoryByClass(class'DesertEagleWeapon');
						break;
					case 1:
						CreateInventoryByClass(class'M870Weapon');
						break;
					case 2:
						CreateInventoryByClass(class'M16A2Weapon');
						break;
					case 3:
						CreateInventoryByClass(class'MaDSPistolWeapon');
						break;
					case 4:
						CreateInventoryByClass(class'MaDSMPWeapon');
						break;
					case 5:
						CreateInventoryByClass(class'EAGSelectWeapon');
						break;
					case 6:
						CreateInventoryByClass(class'EAGlockAkimboWeapon');
						break;
					case 7:
						CreateInventoryByClass(class'EABerettaWeapon');
						break;
					case 8:
						CreateInventoryByClass(class'EAMP5Weapon');
						break;
					case 9:
						CreateInventoryByClass(class'EAIngramWeapon');
						break;
				}
			}

			// And bump them up to be ready to fight
			if(PainThreshold < 1.0)
				PainThreshold = 1.0;

			if(Cajones < 1.0)
				Cajones = 1.0;

			// Make them block melee attacks more often
			if (BlockMeleeFreq < MELEE_BLOCK_MIN_INSANE)
				BlockMeleeFreq = frand() * (MELEE_BLOCK_MAX_INSANE - MELEE_BLOCK_MIN_INSANE) + MELEE_BLOCK_MIN_INSANE;
		}

		// tell the weapons they've been made now
		thisinv = Inventory;
		while(thisinv != None)
		{
			if(P2Weapon(thisinv) != None)
			{
				// After the creation of the weapon, while  normal weapons link up their ammo,
				// we wait and finally link up the urethra. Don't do it above, during the creation
				// of the weapon, it must wait till here.
				if(UrethraWeapon(thisinv) != None)
				{
					MyUrethra = Weapon(thisinv);
					MyUrethra.GiveAmmo(self);
					ClientSetUrethra(P2Weapon(thisinv));
				}

				P2Weapon(thisinv).bJustMade=false;
			}
			thisinv = thisinv.inventory;
			Count++;
			if (Count > 5000)
				break;
		}

		// Switch them as a default, to use their hands
		if(PersonController(Controller) != None)
			PersonController(Controller).SwitchToThisWeapon(StartWeapon_Group, StartWeapon_Offset);

		// If you're using distance-based weapon changing, then save the weapons to use
		if(WeapChangeDist > 0)
		{
			if(BaseEquipment.Length >= 2)
			{
				if(BaseEquipment[CloseWeaponIndex].weaponclass != None)
					CloseWeap = class<P2Weapon>(BaseEquipment[CloseWeaponIndex].weaponclass);
				if(CloseWeap == None)
					log(self$" ERROR: WeapChangeDist and Close weapon is invalid!");

				if(BaseEquipment[FarWeaponIndex].weaponclass != None)
					FarWeap = class<P2Weapon>(BaseEquipment[FarWeaponIndex].weaponclass);
				if(FarWeap == None)
					log(self$" ERROR: WeapChangeDist and Far weapon is invalid!");
			}
			else
			{
				log(self$" ERROR: WeapChangeDist set with only 1 weapon!");
				WeapChangeDist = 0;
			}
		}

		// Note that we got our default inventory
		bGotDefaultInventory = true;

		//log(self$" in they hate me: "$P2GameInfo(Level.Game).TheyHateMeMode()$" game diff "$P2GameInfo(Level.Game).GameDifficulty);
		// If you're in They Hate Me mode, make everyone hate the player.
		// Do this at the end, so we don't retry to do this whole function again in
		// the new Possess, should redo our controller (below)
		if(P2GameInfo(Level.Game).TheyHateMeMode()
			&& !bPlayer)
		{
			// Leave innocents and cashiers alone. Hostiles get
			// made more hostile.
			if(bHasViolentWeapon)
			{
				bPlayerIsEnemy=true;
				bPlayerIsFriend=false;
				// And bump them up to be ready to fight, if they have a weapon
				if(PainThreshold < 1.0)
					PainThreshold = 1.0;
				if(Cajones < 1.0)
					Cajones = 1.0;

				if(CashierController(Controller) == None)
				{
					// If you were a Cop/Military, then turn into a cop-like bystander
					// so you don't try arrests or anything like that.
					if(Controller.IsA('PoliceController')
						|| Controller.IsA('RWSController')
						|| Controller.IsA('RedneckController')
						|| Controller.IsA('KumquatController'))
					{
						Controller.Destroy();
						Controller = None;
						Controller = spawn(class'EACivilianController');
						if(Controller != None )
						{
							Controller.Possess(self);
							AIController(Controller).Skill += SkillModifier;
							CheckForAIScript();
						}
					}
				}
			}
		}

		// Make sure *un-armed* bystanders take one pistol bullet if you hit them exactly in the middle
		if(!bHasViolentWeapon
			&& bInnocent)
		{
			// Calculate pistol damage for one hit kills.
			usedam = class'PistolBulletAmmoInv'.default.DamageAmount*class'Dude'.default.DamageMult - 1;
			//log(self$" new health "$usedam);
			HealthMax = usedam;
			Health = HealthMax;
		}
		//log(self$" initting for new level, game info diff "$P2GameInfoSingle(Level.Game).GameDifficulty$" game state diff "$P2GameInfoSingle(Level.Game).TheGameState.GameDifficulty$" GET game state diff "$P2GameInfoSingle(Level.Game).GetGameDifficulty());
	}
	//else
	//{
	//	Log(self$" PersonPawn.AddDefaultInventory() is being bypassed because inventory was added already");
	//}
}

///////////////////////////////////////////////////////////////////////////////
///////////////////////////////////////////////////////////////////////////////
simulated function PlayCellIn()
{
	PersonController(Controller).SwitchToThisWeapon(CellPhoneClass.default.InventoryGroup, CellPhoneClass.default.GroupOffset);
//	PlayAnim('s_idle_cellin', 1.0, 0.2);
}

simulated function PlayCellOut()
{
	PlayAnim('s_idle_cellout', 1.0, 0.2);
	PlaySound(CellBeep, SLOT_TALK);
	PersonController(Controller).SwitchToHands();
}

simulated function PlayCellOn()
{
	PlayAnim('s_idle_cellon2', 1.1, 0.2);
	PlaySound(CellBeep, SLOT_TALK);
}

simulated function PlayCellLoop()
{
	PlayAnim('s_idle_cell', 0.8);
}

simulated function float PlayIncomingCall()
{
	PlaySound(CellRing, SLOT_TALK);
	return GetSoundDuration(CellRing);
}

///////////////////////////////////////////////////////////////////////////////
// Record pawn dead, if player killed them
///////////////////////////////////////////////////////////////////////////////
function Died(Controller Killer, class<DamageType> damageType, vector HitLocation)
{
	if(P2GameInfoSingle(Level.Game) != None
		&& P2GameInfoSingle(Level.Game).TheGameState != None
		&& EAGameState(P2GameInfoSingle(Level.Game).TheGameState) != None
		&& Killer != None
		&& Killer.bIsPlayer)
	{
		// Record the pawn as an innocent, if we don't hate the player.
		if (bInnocent)
			EAGameState(P2GameInfoSingle(Level.Game).TheGameState).InnocentsKilled++;
	}

	Super.Died(Killer, damageType, HitLocation);
}

///////////////////////////////////////////////////////////////////////////////
// Set dialog class
///////////////////////////////////////////////////////////////////////////////
function SetDialogClass()
{
	// This must be checked for None here. The default properties on Gary or Habib
	// set his voice, then we want to preserve that and not reset it here to a white male.
	if(DialogClass == None)
	{
		if (bIsFemale)
			DialogClass=class'EADialog.EADialogFemale';
		else
			DialogClass=class'EADialog.EADialogMale';
	}
}

///////////////////////////////////////////////////////////////////////////////
///////////////////////////////////////////////////////////////////////////////
auto simulated state Living
{
	event Tick(float DeltaTime)
	{
		Super.Tick(DeltaTime);

		// Unsticking logic for NPCs.
        if (!Controller.bIsPlayer && DetectStuckPlayer(DeltaTime))
			HandleStuckPlayer();
	}

	///////////////////////////////////////////////////////////////////////////////
	// Check to change footstep speed
	///////////////////////////////////////////////////////////////////////////////
	simulated function SetWalking(bool bNewIsWalking)
	{
		local bool OldWalking;

		OldWalking = bIsWalking;

		Super.SetWalking(bNewIsWalking);

		if ( bNewIsWalking != OldWalking )
		{
			Timer();
		}
	}

	///////////////////////////////////////////////////////////////////////////////
	//  Play sound
	///////////////////////////////////////////////////////////////////////////////
	simulated function Timer()
	{
		local float vol, usepitch, userad;
		local vector usevel;
		local bool bOtherMp; // someone other than you

//		log(self$" timer, phys "$Physics$" walking "$bIsWalking$" velocity "$Velocity$" role "$Role$" viewport "$ViewPort(PlayerController(Controller).Player));

		// only on client or stand alone
		// don't play footsteps during cinema
		// also don't play footsteps while deathcrawling
		if(bDoFootsteps && !P2GameInfo(Level.Game).IsCinematic() && !bIsDeathCrawling)
		{
			bPlayingFootstepSound=false;

			if ( Physics == PHYS_Walking )
			{
				usepitch=1.0;
				if(bIsWalking
					|| bIsCrouched)
				{
					vol = WALK_VOL;
					SetTimer(WALK_FOOTSTEP_TIME, false);
				}
				else
				{
					vol = RUN_VOL;
					SetTimer(RUN_FOOTSTEP_TIME, false);
				}

				usepitch=1.0;
				userad = FOOTSTEP_RADIUS;

				if(VSize(Velocity) > 0)
				{
					PlaySound(FootStepSounds[Rand(ArrayCount(FootStepSounds))],SLOT_Interact,vol,,userad,usepitch);
					bPlayingFootstepSound=true;
				}
			}
			else
				SetTimer(WALK_FOOTSTEP_TIME, false);
		}
	}
	simulated function BeginState()
	{
//		log(self$" beginstate Living, role "$Role$" remote "$RemoteRole);
		SetTimer(RUN_FOOTSTEP_TIME, false);
	}
}

///////////////////////////////////////////////////////////////////////////////
// Chop person in half
//
// Doesn't check if they still have a whole body to slice in half--just
// does it anyway, so be careful! Check bMissingTop/BottomHalf first.
///////////////////////////////////////////////////////////////////////////////
function ChopInHalf(Pawn InstigatedBy, out vector momentum, out int Damage,
					out vector TrueHitLoc)
{
	local AWPerson bottomh;
	local coords usecoords;
	local rotator userot;
	local float Animf, AnimR;
	local name CurrAnim;
	local Actor HitActor;
	local vector HitLocation, HitNormal, checkpoint;
	local PawnExplosion exp;
	local bool bTopHalfStartedAlive;

	// Mark the bottom as missing becuase we're turning this bone into
	// the top half, and your missing your legs
	bMissingBottomHalf=true;
	bMissingLegParts=true;
	bMissingLimbs=true;

	// Save if we started alive or not for the bottom half to know how to animate if no ragdoll is around
	if(Health > 0)
		bTopHalfStartedAlive=true;

	// Make sure it kills them
	Damage = Health;

	// Do effects
	PlaySound(CutInHalfSound,,,,,GetRandPitch());
	spawn(class'LimbExplode',self,,Location);

	// Shrink bottom half
	// Shrink everything down all over, to very small. This number
	// must be greater than 0, or the matrices for the bones will be lots
	SetBoneScale(TORSO_INDEX, 1/SHRINK_PELVIS, BONE_PELVIS);
	// Grow it back up, but only for the top of the body
	SetBoneScale(TORSO_INDEX+1, SHRINK_PELVIS, TOP_TORSO);
	// Pop up the top half some
	momentum = VRand();
	momentum.z=0;
	momentum = (TopMomMag)*Normal(momentum);
	momentum.z += TopMomMag;
	TrueHitLoc.z+=(CollisionHeight/2); // make it hit above the center some for some spin
	// Turn off your collision
	SetCollision(false, false, false);
	// Make the bottom half, starting with the proper orientation
	usecoords = GetBoneCoords(BONE_PELVIS);
	userot = Rotator(usecoords.YAxis);
	userot.Yaw-=32768;
	// Check if they are too close to the ground to spawn
	checkpoint = Location;
	checkpoint.z-=CollisionHeight;
	HitActor = Trace(HitLocation, HitNormal, checkpoint, Location, true);
	if(HitActor != None)
	{
		// Move it up, off the ground
		HitLocation.z+=(1.5*CollisionHeight);
	}
	else // it's find where it is
		HitLocation = Location;

	// Add stumps for top half
	HalfTorsoStumps();

	// Spawn the bottom half
	bottomh = spawn(class,Owner,,HitLocation);
	if(bottomh != None)
	{
		bottomh.bBottomHalfNewSpawn=true;
		// Remove head
		bottomh.DestroyHead();
		// Move bolt-ons from the bottom
		bottomh.DestroyBoltons();
		// Set mesh as the same
		bottomh.SetMyMesh(Mesh);
		// Make sure the bottom looks the same as the top
		bottomh.Skins[0] = Skins[0];
		// Set our clothing now that our skin is set, reset them first, then recheck them in the functions
		bottomh.bSkirt=false;
		bottomh.bPants=false;
		bottomh.DetermineClothing(GetItemName(String(Skins[0])));
		bottomh.DetermineClothing(GetItemName(String(Mesh)));
		// Get current anim 
		GetAnimParams(0, CurrAnim, AnimF, AnimR);
		bottomh.ShouldCower(bIsCowering);
		bottomh.ShouldCrouch(bIsCrouched);
		bottomh.ShouldDeathCrawl(bIsDeathCrawling);
		// Play anim same as current one, but make it start at the end
		bottomh.PlayAnimAt(CurrAnim, 1.0, 0.0, 0, 1.0);
		if(!bTopHalfStartedAlive)
			bottomh.bBottomWarpDeathAnim=true;
		// Shrink top half
		bottomh.SetBoneScale(TORSO_INDEX, 0.0, TOP_TORSO);
		// Kill it to turn it into karma/animation
		bottomh.Health=0;
		bottomh.OldTopHalfRotationKarma=userot;
		bottomh.OldTopHalfRotationAnim=Rotation;
		bottomh.PlayDying(class'ScytheDamage', Location);
		// And you're the bottom, that's missing it's top, including your arms
		bottomh.bMissingTopHalf=true;
		bottomh.bMissingLimbs=true;
		bottomh.BoneArr[LEFT_ARM]=0;
		bottomh.BoneArr[LEFT_ARM+1]=0;
		bottomh.BoneArr[RIGHT_ARM]=0;
		bottomh.BoneArr[RIGHT_ARM+1]=0;

		// Add stumps for bottom half
		HalfPelvisStumps(bottomh);

		// set the ragdoll in motion
		bottomh.TakeDamage(Damage, InstigatedBy, TrueHitLoc, Momentum, class'P2Damage');
	}
	else // couldn't make the bottom, so make some explosion effects to show something happened
	{
		exp = spawn(class'PawnExplosion',,,usecoords.origin);
		exp.FitToNormal(usecoords.YAxis);
		// Check if the body had any missing legs
		// We didn't make the bottom half, but we still want to remove the stumps,
		// sending in None for our bottom half will do that for us.
		TransferStump(LEFT_LEG, class'Stump'.default.LeftLegI, None);
		TransferStump(RIGHT_LEG, class'Stump'.default.RightLegI, None);
	}

	// Make sure your legs are really gone too
	// Do this later, because the bottom half needs to know about missing limbs
	BoneArr[LEFT_LEG]=0;
	BoneArr[LEFT_LEG+1]=0;
	BoneArr[RIGHT_LEG]=0;
	BoneArr[RIGHT_LEG+1]=0;
	// Turn collision back on
	SetCollision(true, false, false);
	// Tell the dude if he did it
	if(AWDude(InstigatedBy) != None)
		AWDude(InstigatedBy).CutHalf(self);
}

///////////////////////////////////////////////////////////////////////////////
// Take damage (pawn call) but also save who attacked me
// Take limbs off in AW.
///////////////////////////////////////////////////////////////////////////////

///////////////////////////////////////////////////////////////////////////////
// Take damage (pawn call) but also save who attacked me
// Take limbs off in AW.
///////////////////////////////////////////////////////////////////////////////
function TakeDamage( int Damage, Pawn instigatedBy, Vector hitlocation,
						Vector momentum, class<DamageType> damageType)
{
	local bool bUseSuper;
	local int actualDamage, StartDamage;
	local Controller Killer;
	local byte StateChange;

	//log(self$" take damage "$damagetype$" takes "$TakesZombieSmashDamage);
	// If we don't have a controller then we're either the player in a movie, or
	// we're an NPC starting out in a pain volume--either way, we don't
	// want to take damage in this state, without a controller.
	// For the player, this gives him god mode, while a movie is playing.
	if(Controller == None)
		return;

	StartDamage = Damage;
	DamageInstigator = instigatedBy;

	if(ClassIsChildOf(damageType, class'SuperShotgunDamage'))
		Damage = TakesScytheDamage*Damage;

	if(// Can't cut off player limbs
		P2Player(Controller) == None)
	{
		// If it's a damage type and hasn't been lowered, allow limb severance
		// but if TakesMacheteDamage (for instance) is less than 1.0, then don't let limbs be cut
		if(ClassIsChildOf(damageType, class'SuperShotgunDamage'))
		{
			if(Damage >= StartDamage)
				bUseSuper = !(HandleScythe(InstigatedBy, momentum, damagetype, Damage, HitLocation));
			else // convert to lower damage type
				damageType = class'ShotgunDamage';
		}
		else
			bUseSuper=true;

	}
	else // Make sure the player picks the super take damage
		bUseSuper=true;

	if(!bUseSuper)
	{
		// Multiply damage as necessary per pawn
		//Damage = FPSPawn(InstigatedBy).DamageMult*Damage;

		// Modify as necessary per game
		actualDamage = Level.Game.ReduceDamage(Damage, self, instigatedBy, HitLocation, Momentum, DamageType);

		// Save the type that just hurt us
		LastDamageType = class<P2Damage>(DamageType);

		// Armor check.
		// Intercept damage, and if you have armor on, and it's a certain type of damage, 
		// modify the damage amount, based on the what hurt you.
		// Armor doesn't do anything for head shots
		if(Armor > 0
			&& bHasHead
			&& (Controller == None
				|| !Controller.bGodMode))
			ArmorAbsorbDamage(instigatedby, actualDamage, DamageType, HitLocation);

		// Don't call at all if you didn't get hurt
		// The above function does a better check on the head, so you may have shot too high or
		// something, at which point, it'll set the damage to 0, causing this to exit early
		if(Damage <= 0)
		{
			// Tell the character about the non-damage. Most of them will ignore this damage
			// but some people (like Krotchy) will use this to do things
			// Report the original damage asked to be delivered as a negative, so it's not
			// used as actual damage, but it's used to know how bad the damage would have been.
			if ( Controller != None )
				Controller.NotifyTakeHit(instigatedBy, HitLocation, -StartDamage, DamageType, Momentum);
			return;
		}

		// Send the real momentum to this function, please
		PlayHit(actualDamage, hitLocation, damageType, Momentum);

		// Take off health from damage
		Health = Health - actualDamage;

		// Check if he's dead
		if ( Health <= 0 )
		{
			// pawn died
			if ( instigatedBy != None )
				Killer = InstigatedBy.GetKillerController();
			if ( bPhysicsAnimUpdate )
				TearOffMomentum = Momentum / Mass;
//			if (DamageType.Default.GibModifier >= 100)
//				BlowOffHeadAndLimbs(InstigatedBy, momentum, Damage);

			Died(Killer, damageType, HitLocation);
		}
		else
		{
			// Don't make things shoot you up into the air unless it's specific damage types
			if(class<P2Damage>(damageType) == None
				|| !class<P2Damage>(damageType).default.bAllowZThrow)
			{
				if(Physics == PHYS_Walking)
					momentum.z=0;
			}
			AddVelocity( momentum );

			// Tell the character about the damage
			if ( Controller != None )
				Controller.NotifyTakeHit(instigatedBy, HitLocation, Damage, DamageType, Momentum);
		}
	}
	else
	{
//		if (Damage >= Health && DamageType.Default.GibModifier >= 100)
//			BlowOffHeadAndLimbs2(InstigatedBy, BlowOffMom, Damage);

		Super.TakeDamage(Damage, InstigatedBy, HitLocation, momentum, damageType);
	}
}


///////////////////////////////////////////////////////////////////////////////
// MP anims copied from Dude
// Most bystanders won't use these, but they're here just in case
///////////////////////////////////////////////////////////////////////////////
simulated event PlayFalling()
	{
		AnimBlendToAlpha(FALLINGCHANNEL,1.0,0.1);
		if ( abs(Velocity.X) > MOVE_BUFFER || abs(Velocity.Y) > MOVE_BUFFER )
		{
			if(bIsWalking)
				PlayAnim('s_walkjumpholdMP', , , FALLINGCHANNEL);
			else
				PlayAnim('s_runjumpholdMP', , , FALLINGCHANNEL);
		}
		else
			PlayAnim('s_jumpholdMP', , , FALLINGCHANNEL);
	}


///////////////////////////////////////////////////////////////////////////////
///////////////////////////////////////////////////////////////////////////////
simulated event PlayJump()
	{
		AnimBlendToAlpha(FALLINGCHANNEL,1.0,0.1);
		if ( abs(Velocity.X) > MOVE_BUFFER || abs(Velocity.Y) > MOVE_BUFFER )
		{
			if(bIsWalking)
				PlayAnim('s_walkjumpMP', , , FALLINGCHANNEL);
			else
				PlayAnim('s_runjumpMP', , , FALLINGCHANNEL);
		}
		else
			PlayAnim('s_jumpMP', , , FALLINGCHANNEL); 
	}


///////////////////////////////////////////////////////////////////////////////
///////////////////////////////////////////////////////////////////////////////
simulated function PlayLanded(float impactVel)
	{
//	BaseEyeHeight = Default.BaseEyeHeight;
		AnimBlendToAlpha(FALLINGCHANNEL,1.0,0.1);
		if ( (Acceleration.X != 0) || (Acceleration.Y != 0) )
		{
			if(bIsWalking)
				PlayAnim('s_walkjumplandMP', , , FALLINGCHANNEL);
			else
				PlayAnim('s_runjumplandMP', , , FALLINGCHANNEL);
		}
		else
			PlayAnim('s_jumplandMP', , , FALLINGCHANNEL);
	/*
	impactVel = impactVel/JumpZ;
	impactVel = 0.1 * impactVel * impactVel;
	if ( impactVel > 0.17 )
		PlayOwnedSound(LandGrunt, SLOT_Talk, FMin(5, 5 * impactVel),false,1200,FRand()*0.4+0.8);
	if ( (impactVel > 0.01) && !TouchingWaterVolume() )
		PlayOwnedSound(Land, SLOT_Interact, FClamp(4 * impactVel,0.5,5), false,1000, 1.0);
	*/
	}

///////////////////////////////////////////////////////////////////////////////
///////////////////////////////////////////////////////////////////////////////
simulated event PlayLandingAnimation(float ImpactVel)
	{
	// STUB
	}



///////////////////////////////////////////////////////////////////////////////
///////////////////////////////////////////////////////////////////////////////
///////////////////////////////////////////////////////////////////////////////
// Dying
///////////////////////////////////////////////////////////////////////////////
///////////////////////////////////////////////////////////////////////////////
///////////////////////////////////////////////////////////////////////////////
state Dying
{
	///////////////////////////////////////////////////////////////////////////////
	// Get hurt, plus some ragdoll
	//
	// Only let you hurt the dead guys in single player, because in MP, the characters
	// won't match up with other people's computers and if you set someone on fire
	// they will be on fire in two different incorrect places (blood would shoot
	// out of weird places too.. ) It just makes a big mess.
	///////////////////////////////////////////////////////////////////////////////
	function TakeDamage( int Damage, Pawn InstigatedBy, Vector Hitlocation,
							Vector Momentum, class<DamageType> DamageType)
	{
		local bool bUseSuper;

		if (MyBodyFire == None)
			MyBodyFire = None;

		if(Level.Game != None
			&& Level.Game.bIsSinglePlayer)
		{
			if(class'P2Player'.static.BloodMode()
				// can't cut off player limbs
				&& P2Player(Controller) == None)
			{
				if(ClassIsChildOf(damageType, class'SuperShotgunDamage'))
					bUseSuper = !(HandleScythe(InstigatedBy, momentum, damagetype, Damage, HitLocation));
				else
					bUseSuper=true;
			}

			if(bUseSuper)
			{
				// Check to cut off limbs, and pass it along to original TakeDamage
				// for momentum transfer
				if(class'P2Player'.static.BloodMode()
					&& ClassIsChildOf(damageType, class'ExplodedDamage'))
					HandleExplosionDead(Damage, InstigatedBy, HitLocation, momentum, damageType);

				Super.TakeDamage(Damage, InstigatedBy, HitLocation, Momentum, DamageType);
			}
		}
	}
}

///////////////////////////////////////////////////////////////////////////////
///////////////////////////////////////////////////////////////////////////////

defaultproperties
{
     CellPhoneClass=Class'AWInventory.CellPhoneWeapon'
     bCellUser=True
     CellBeep=Sound'AWSoundFX.Phone.phonebeep'
     cellring=Sound'AWSoundFX.Phone.cellring'
     FootStepSounds(0)=Sound'MoreMiscSounds.loudfootsteps.footstep1h'
     FootStepSounds(1)=Sound'MoreMiscSounds.loudfootsteps.footstep2h'
     FootStepSounds(2)=Sound'MoreMiscSounds.loudfootsteps.footstep4h'
     FootStepSounds(3)=Sound'MoreMiscSounds.loudfootsteps.footstep5h'
     FootStepSounds(4)=Sound'MoreMiscSounds.loudfootsteps.footstep6h'
     bDoFootsteps=True
     EDMeshAnims(0)=MeshAnimation'ED_Characters.avgMental'
     EDMeshAnims(1)=MeshAnimation'ED_Characters.ED_deadBody'
     EDMeshAnims(2)=MeshAnimation'ED_Characters.rws_aw_anims_zomb'
     EDMeshAnims(3)=MeshAnimation'ED_Characters.smockingtostand'
     EDMeshAnims(4)=MeshAnimation'ED_Characters.SYS_HEDGETRIMMER'
     EDMeshAnims(5)=MeshAnimation'ED_Characters.ED_Scope_Slit_throat'
     EDMeshAnims(6)=MeshAnimation'ED_Characters.SyS_fisting'
     EDMeshAnims(7)=MeshAnimation'ED_Characters.GroundExit'
     EDMeshAnims(8)=MeshAnimation'ED_Characters.returntolifeFloaty'
     EDMeshAnims(9)=MeshAnimation'MP_Characters.anim_MP'
     EDMeshAnims(10)=MeshAnimation'ED_Characters.FLIGHTPACK'
     EDMeshAnims(11)=MeshAnimation'ED_Characters.animMaD'
     EDMeshAnims(12)=MeshAnimation'ED_ScopeNewCharacters.ScopesZombie1'
     EDMeshAnims(13)=MeshAnimation'MaD_ED_MP_Strippers.anim_StripperMP'
     EDMeshAnims(14)=MeshAnimation'Characters.animBig'
     EDMeshAnims(15)=MeshAnimation'AWCharacters.animAvg_AW'
//     EDMeshAnims(16)=MeshAnimation'Characters.animFem'
//     EDMeshAnims(2)=MeshAnimation'ED_Characters.SilentScope_XombiesFinal'
     SeverBone(0)="MALE01 L UpperArm"
     SeverBone(1)="MALE01 L Forearm"
     SeverBone(2)="MALE01 R UpperArm"
     SeverBone(3)="MALE01 R Forearm"
     SeverBone(4)="MALE01 L Thigh"
     SeverBone(5)="MALE01 L Calf"
     SeverBone(6)="MALE01 R Thigh"
     SeverBone(7)="MALE01 r calf"
     BoneArr(0)=1
     BoneArr(1)=1
     BoneArr(2)=1
     BoneArr(3)=1
     BoneArr(4)=1
     BoneArr(5)=1
     BoneArr(6)=1
     BoneArr(7)=1
     StumpBloodClass=Class'EDPawnsBase.EDStumpBlood'
     LimbClass=Class'EAPawns.EALimb'
     HeadClass=Class'EAFX.EAHead'
     BodyHitSounds(0)=Sound'MiscSounds.People.bodyhitground1'
     BodyHitSounds(1)=Sound'MiscSounds.People.bodyhitground2'
     HeadMomMag=5000.000000
     LimbMomMag=5000.000000
     TopMomMag=9000.000000
     ChameleonMeshPkgs(0)="Characters"
     ChamelHeadSkins(0)="ChamelHeadSkins.MWA__001__AvgMale"
     ChamelHeadSkins(1)="ChamelHeadSkins.MBA__013__AvgBrotha"
     ChamelHeadSkins(2)="ChamelHeadSkins.MBA__014__AvgBrotha"
     ChamelHeadSkins(3)="ChamelHeadSkins.MMA__016__AvgMale"
     ChamelHeadSkins(4)="ChamelHeadSkins.MMF__024__FatMale"
     ChamelHeadSkins(5)="ChamelHeadSkins.MWA__002__AvgMale"
     ChamelHeadSkins(6)="ChamelHeadSkins.MMA__003__AvgMale"
     ChamelHeadSkins(7)="ChamelHeadSkins.MWA__004__AvgMale"
     ChamelHeadSkins(8)="ChamelHeadSkins.MWA__005__AvgMale"
     ChamelHeadSkins(9)="ChamelHeadSkins.MWA__006__AvgMale"
     ChamelHeadSkins(10)="ChamelHeadSkins.MWA__007__AvgMale"
     ChamelHeadSkins(11)="ChamelHeadSkins.MWA__008__AvgMale"
     ChamelHeadSkins(12)="ChamelHeadSkins.MWA__009__AvgMale"
     ChamelHeadSkins(13)="ChamelHeadSkins.MWA__010__AvgMale"
     ChamelHeadSkins(14)="ChamelHeadSkins.MWA__011__AvgMale"
     ChamelHeadSkins(15)="ChamelHeadSkins.MWA__015__AvgMale"
     ChamelHeadSkins(16)="ChamelHeadSkins.MWA__021__AvgMaleBig"
     ChamelHeadSkins(17)="ChamelHeadSkins.MWA__035__AvgMale"
     ChamelHeadSkins(18)="ChamelHeadSkins.MWF__025__FatMale"
     ChamelHeadSkins(19)="ChamelHeadSkins.MWA__022__AvgMaleBig"
     ChamelHeadSkins(20)="ChamelHeadSkins.FBA__033__FemSH"
     ChamelHeadSkins(21)="ChamelHeadSkins.FMA__028__FemSH"
     ChamelHeadSkins(22)="ChamelHeadSkins.FMA__034__FemSH"
     ChamelHeadSkins(23)="ChamelHeadSkins.FWA__026__FemLH"
     ChamelHeadSkins(24)="ChamelHeadSkins.FWA__027__FemLH"
     ChamelHeadSkins(25)="ChamelHeadSkins.FWA__029__FemSH"
     ChamelHeadSkins(26)="ChamelHeadSkins.FWA__032__FemSH"
     ChamelHeadSkins(27)="ChamelHeadSkins.FWF__023__FatFem"
     ChamelHeadSkins(28)="ChamelHeadSkins.FWA__037__FemSHcropped"
     ChamelHeadSkins(29)="ChamelHeadSkins.FMA__038__FemSHcropped"
     ChamelHeadSkins(30)="ChamelHeadSkins.FMA__039__FemSHcropped"
     ChamelHeadSkins(31)="ChamelHeadSkins.FWA__040__FemSHcropped"
     ChamelHeadSkins(32)="ChamelHeadSkins.MBF__042__FatMale"
     ChamelHeadSkins(33)="ChamelHeadSkins.FBF__043__FatFem"
     ChamelHeadSkins(34)="ChamelHeadSkins.FMF__044__FatFem"
     ChamelHeadSkins(35)="ChamelHeadSkins.FWA__031__FemSH"
     ChamelHeadSkins(36)="ChamelHeadSkins.FBA__063__FemSH"
     ChamelHeadSkins(37)="ED_HeadsAndSkins.Tim_Wambolts.FWA__030__FemSH"
     ChamelHeadSkins(38)="ED_HeadsAndSkins.biohazardous_snarks.MBA__021__AvgBrotha"
     ChamelHeadSkins(39)="ED_HeadsAndSkins.biohazardous_snarks.MBA__022__AvgBrotha"
     ChamelHeadSkins(40)="ED_HeadsAndSkins.biohazardous_snarks.MBA__023__AvgBrotha"
     ChamelHeadSkins(41)="ED_HeadsAndSkins.Tim_Wambolts.FWA__030__FemLH"
     ChamelHeadSkins(42)="ED_HeadsAndSkins.biohazardous_snarks.MBA__024__AvgBrotha"
     ChamelHeadSkins(43)="ED_HeadsAndSkins.biohazardous_snarks.MWA__001__AvgMale"
     ChamelHeadSkins(44)="ED_HeadsAndSkins.biohazardous_snarks.MWA__002__AvgMale"
     ChamelHeadSkins(45)="ED_HeadsAndSkins.biohazardous_snarks.MWA__003__AvgMale"
     ChamelHeadSkins(46)="ED_HeadsAndSkins.biohazardous_snarks.MWA__004__AvgMale"
     ChamelHeadSkins(47)="ED_HeadsAndSkins.biohazardous_snarks.MWA__005__AvgMale"
     ChamelHeadSkins(48)="ED_HeadsAndSkins.biohazardous_snarks.FWA__244__FemSH"
     ChamelHeadSkins(49)="ED_HeadsAndSkins.Mimics.MMA__007__AvgMale"
     ChamelHeadSkins(50)="ED_HeadsAndSkins.Steevees.MWA__409__AvgMale"
     ChamelHeadSkins(51)="ED_HeadsAndSkins.Steevees.MWA__410__AvgMale"
     ChamelHeadSkins(52)="ED_HeadsAndSkins.Steevees.MWA__411__AvgMale"
     ChamelHeadSkins(53)="ED_HeadsAndSkins.Steevees.MWA__012__AvgMale"
     ChamelHeadSkins(54)="ED_HeadsAndSkins.Steevees.MWA__013__AvgMale"
     ChamelHeadSkins(55)="ED_HeadsAndSkins.Steevees.MWA__014__AvgMale"
     ChamelHeadSkins(56)="ED_HeadsAndSkins.Steevees.MWA__015__AvgMale"
     ChamelHeadSkins(57)="ED_HeadsAndSkins.Steevees.MWA__016__AvgMale"
     ChamelHeadSkins(58)="ED_HeadsAndSkins.Steevees.MWA__017__AvgMale"
     ChamelHeadSkins(59)="ED_HeadsAndSkins.Tim_Wambolts.MWA__018__AvgMale"
     ChamelHeadSkins(60)="ED_HeadsAndSkins.Tim_Wambolts.MWA__019__AvgMale"
     ChamelHeadSkins(61)="ED_HeadsAndSkins.Tim_Wambolts.MWA__020__AvgMale"
     ChamelHeadSkins(62)="ED_HeadsAndSkins.SniperX.MWA__008__AvgMale"
     ChamelHeadSkins(63)="ED_HeadsAndSkins.biohazardous_snarks.MWA__006__AvgMale"
     ChamelHeadSkins(64)="ED_HeadsAndSkins.biohazardous_snarks.MWA__007__AvgMale"
     ChamelHeadSkins(65)="ED_HeadsAndSkins.biohazardous_snarks.MWA__008__AvgMale"
     ChamelHeadSkins(66)="ED_HeadsAndSkins.biohazardous_snarks.MMA__009__AvgMale"
     ChamelHeadSkins(67)="ED_HeadsAndSkins.biohazardous_snarks.MWA__010__AvgMale"
     ChamelHeadSkins(68)="ED_HeadsAndSkins.biohazardous_snarks.MWA__011__AvgMale"
     ChamelHeadSkins(69)="ED_HeadsAndSkins.Steevees.FWA__025__FemSH"
     ChamelHeadSkins(70)="ED_HeadsAndSkins.Tim_Wambolts.FWA__026__FemSH"
     ChamelHeadSkins(71)="ED_HeadsAndSkins.Tim_Wambolts.FWA__027__FemSH"
     ChamelHeadSkins(72)="ED_HeadsAndSkins.Tim_Wambolts.FWA__028__FemLH"
     ChamelHeadSkins(73)="ED_HeadsAndSkins.Tim_Wambolts.FWA__029__FemSH"
     ChamelHeadSkins(74)="ED_HeadsAndSkins.Tim_Wambolts.FWA__237__FemSHcropped"
     ChamelHeadSkins(75)="ED_HeadsAndSkins.Tim_Wambolts.FWA__238__FemSHcropped"
     ChamelHeadSkins(76)="ED_HeadsAndSkins.Tim_Wambolts.FWA__031__FemSH"
     ChamelHeadSkins(77)="ED_HeadsAndSkins.Tim_Wambolts.FWA__242__FemSH"
     ChamelHeadSkins(78)="ED_HeadsAndSkins.Tim_Wambolts.FWA__243__FemSH"
     ChamelHeadSkins(80)="ED_HeadsAndSkins.biohazardous_snarks.MWA__010__AvgMale"
     ChamelHeadSkins(81)="ED_HeadsAndSkins.biohazardous_snarks.MWA__011__AvgMale"
     ChamelHeadSkins(82)="AW7PawnSkins.heads.FWA__218__FemSH"
     ChamelHeadSkins(83)="AW7PawnSkins.heads.FWA__228__FemLH"
     ChamelHeadSkins(84)="AW7PawnSkins.heads.FWA__229__FemSH"
     ChamelHeadSkins(85)="AW7PawnSkins.heads.FWA__230__FemSH"
     ChamelHeadSkins(86)="AW7PawnSkins.heads.FWA__231__FemSHCropped"
     ChamelHeadSkins(87)="AW7PawnSkins.heads.FWA__232__FemSHCropped"
     ChamelHeadSkins(88)="AW7PawnSkins.heads.FWA__233__FemSHcropped"
     ChamelHeadSkins(89)="AW7PawnSkins.heads.FWA__234__FemSH"
     ChamelHeadSkins(90)="AW7PawnSkins.heads.FWA__235__FemSH"
     ChamelHeadSkins(91)="AW7PawnSkins.heads.FWA__242__FemSH"
     ChamelHeadSkins(92)="AW7PawnSkins.heads.MBA__201__AvgBrotha"
     ChamelHeadSkins(93)="AW7PawnSkins.heads.MBA__203__AvgBrotha"
     ChamelHeadSkins(94)="AW7PawnSkins.heads.MMA__204__AvgMale"
     ChamelHeadSkins(95)="AW7PawnSkins.heads.MMA__216__AvgMale"
     ChamelHeadSkins(96)="AW7PawnSkins.heads.MWA__200__AvgMaleBig"
     ChamelHeadSkins(97)="AW7PawnSkins.heads.MWA__202__AvgMale"
     ChamelHeadSkins(98)="AW7PawnSkins.heads.MWA__205__AvgMale"
     ChamelHeadSkins(99)="AW7PawnSkins.heads.MWA__206__AvgMale"
     ChamelHeadSkins(100)="AW7PawnSkins.heads.MWA__207__AvgMale"
     ChamelHeadSkins(101)="AW7PawnSkins.heads.MWA__208__AvgMale"
     ChamelHeadSkins(102)="AW7PawnSkins.heads.MWA__209__AvgMale"
     ChamelHeadSkins(103)="AW7PawnSkins.heads.MWA__210__AvgMale"
     ChamelHeadSkins(104)="AW7PawnSkins.heads.MWA__211__AvgMale"
     ChamelHeadSkins(105)="AW7PawnSkins.heads.MWA__212__AvgMale"
     ChamelHeadSkins(106)="AW7PawnSkins.heads.MWA__213__AvgMale"
     ChamelHeadSkins(107)="AW7PawnSkins.heads.MWA__215__AvgMale"
     ChamelHeadSkins(108)="AW7PawnSkins.heads.MWA__217__AvgMale"
     ChamelHeadSkins(109)="AW7PawnSkins.heads.MWA__219__AvgMale"
     ChamelHeadSkins(110)="AW7PawnSkins.heads.MWA__220__AvgMale"
     ChamelHeadSkins(111)="AW7PawnSkins.heads.MWA__221__AvgMale"
     ChamelHeadSkins(112)="AW7PawnSkins.heads.MWA__222__AvgMale"
     ChamelHeadSkins(113)="AW7PawnSkins.heads.MWA__223__AvgMale"
     ChamelHeadSkins(114)="AW7PawnSkins.heads.MWA__224__AvgMale"
     ChamelHeadSkins(115)="AW7PawnSkins.heads.MWA__225__AvgMale"
     ChamelHeadSkins(116)="AW7PawnSkins.heads.MWA__226__AvgMale"
     ChamelHeadSkins(117)="AW7PawnSkins.heads.MWA__227__AvgMale"
     ChamelHeadSkins(118)="AW7PawnSkins.heads.MWA__236__AvgMale"
     ChamelHeadSkins(119)="AW7PawnSkins.heads.MWA__237__AvgMale"
     ChamelHeadSkins(120)="AW7PawnSkins.heads.MWA__238__AvgMale"
     ChamelHeadSkins(121)="AW7PawnSkins.heads.MWA__239__AvgMaleBig"
     ChamelHeadSkins(122)="AW7PawnSkins.heads.MWA__240__AvgMale"
     ChamelHeadSkins(123)="AW7PawnSkins.heads.MWA__241__AvgMale"
     ChamelHeadSkins(124)="AW7PawnSkins.heads.MWA__243__AvgMale"
     ChamelHeadSkins(125)="AW7PawnSkins.heads.MWA__244__AvgMaleBig"
     ChamelHeadSkins(126)="AW7PawnSkins.heads.MWA__245__AvgMaleBig"
     ChamelHeadSkins(127)="AW7PawnSkins.heads.MWA__247__AvgMale"
     ChamelHeadSkins(129)="End"
     ChamelHeadMeshPkgs(0)="heads"
     AmbientGlow=0
     TakesMachinegunDamage=1.000000
     TakesPistolHeadShot=1.000000
     TakesShotgunHeadShot=1.000000
     TakesRifleHeadShot=1.000000
     TakesShovelHeadShot=1.000000
     TakesOnFireDamage=1.000000
     TakesAnthraxDamage=1.000000
     TakesChemDamage=1.000000
     TakesShockerDamage=1.000000
     TakesSledgeDamage=1.000000
     TakesMacheteDamage=1.000000
     TakesScytheDamage=1.000000
     TakesDervishDamage=1.000000
     TakesZombieSmashDamage=1.000000
     ControllerClass=Class'EAPawns.EACivilianController'
}
